@@ -64,10 +64,12 @@ const bool ConfigItems::load()
 {
     std::string path_conf = CACHE::path_conf();
 
-    // 新設定ファイルが無かったら旧ファイルから読み込む
-    if( CACHE::file_exists( path_conf ) != CACHE::EXIST_FILE ){
+    // 新設定ファイルが無く、かつキャッシュディレクトリが存在していたら旧ファイルから設定を引き継ぐ
+    if( CACHE::file_exists( path_conf ) != CACHE::EXIST_FILE
+        && CACHE::file_exists( CACHE::path_root() ) == CACHE::EXIST_DIR
+        && CACHE::file_exists( CACHE::path_conf_old() ) == CACHE::EXIST_FILE ){
 
-        if( CACHE::file_exists( CACHE::path_conf_old() ) == CACHE::EXIST_FILE ) path_conf = CACHE::path_conf_old();
+            path_conf = CACHE::path_conf_old();
     }
 
     JDLIB::ConfLoader cf( path_conf, std::string() );
@@ -77,11 +79,17 @@ const bool ConfigItems::load()
               << "conffile = " << path_conf << " empty = " << cf.empty() << std::endl;
 #endif
 
+    // 色
+    set_colors( cf );
+
     // 前回開いたviewを復元するか
     restore_board = cf.get_option( "restore_board", CONF_RESTORE_BOARD );
     restore_article = cf.get_option( "restore_article", CONF_RESTORE_ARTICLE );
     restore_image = cf.get_option( "restore_image", CONF_RESTORE_IMAGE );
 
+    // 自前でウィンドウ配置を管理する
+    manage_winpos = cf.get_option( "manage_winpos", CONF_MANAGE_WINPOS );
+
     std::string defaultfont = get_default_font();
 
     // フォント
@@ -105,10 +113,10 @@ const bool ConfigItems::load()
     // レスを参照するときに前に付ける文字
     ref_prefix = cf.get_option( "ref_prefix", CONF_REF_PREFIX );
 
-    // 参照文字( CONF_REF_PREFIX ) の後のスペースの数
+    // 参照文字( ref_prefix ) の後のスペースの数
     // JDLIB::ConfLoader の中で MISC::remove_space() が呼ばれて空白が消えるので別設定とした
     ref_prefix_space = cf.get_option( "ref_prefix_space", CONF_REF_PREFIX_SPACE );
-    for( int i = 0; i < ref_prefix_space; ++i ) ref_prefix += " ";
+    for( int i = 0; i < ref_prefix_space; ++i ) ref_prefix_space_str += " ";
 
     // キャッシュのルートディレクトリ(旧バージョンとの互換のため残している)
     path_cacheroot = cf.get_option( "path_cacheroot", CONF_PATH_CACHEROOT );
@@ -129,10 +137,10 @@ const bool ConfigItems::load()
     proxy_port_for_data = cf.get_option( "proxy_port_for_data", CONF_PROXY_PORT_FOR_DATA );
 
     // 2ch にアクセスするときのエージェント名
-    agent_for2ch = cf.get_option( "agent_for2ch", AGENT_FOR2CH );
+    agent_for2ch = cf.get_option( "agent_for2ch", CONF_AGENT_FOR2CH );
 
     // 2ch外にアクセスするときのエージェント名
-    agent_for_data = cf.get_option( "agent_for_data", AGENT_FOR_DATA );
+    agent_for_data = cf.get_option( "agent_for_data", CONF_AGENT_FOR_DATA );
 
     // 2ch にログインするときのX-2ch-UA
     x_2ch_ua = cf.get_option( "x_2ch_ua", CONF_X_2CH_UA );
@@ -196,16 +204,16 @@ const bool ConfigItems::load()
     max_img_pixel = cf.get_option( "max_img_pixel", CONF_MAX_IMG_PIXEL );
 
     // JD ホームページのアドレス
-    url_jdhp = cf.get_option( "url_jdhp", CONF_JDHP );
+    url_jdhp = cf.get_option( "url_jdhp", CONF_URL_JDHP );
 
     // 2chの認証サーバ
     url_login2ch = cf.get_option( "url_login2ch", CONF_LOGIN2CH );
 
     // bbsmenu.htmlのURL
-    url_bbsmenu = cf.get_option( "url_bbsmenu", CONF_BBSMENU );
+    url_bbsmenu = cf.get_option( "url_bbsmenu", CONF_URL_BBSMENU );
 
     // bbsmenu.html内にあるリンクは全て板とみなす
-    use_link_as_board = cf.get_option( "use_link_as_board", CONF_LINK_AS_BOARD );
+    use_link_as_board = cf.get_option( "use_link_as_board", CONF_USE_LINK_AS_BOARD );
 
     // スレタイ検索用メニュータイトルアドレス
     menu_search_title = cf.get_option( "menu_search_title", CONF_MENU_SEARCH_TITLE );
@@ -218,117 +226,15 @@ const bool ConfigItems::load()
     menu_search_web = cf.get_option( "menu_search_web", CONF_MENU_SEARCH_WEB );
     url_search_web = cf.get_option( "url_search_web", CONF_URL_SEARCH_WEB );
 
-    /////////
-    // 色
-
-    // 文字色
-    str_color[ COLOR_CHAR ] = cf.get_option( "cl_char", CONF_COLOR_CHAR );
-
-    // 名前欄の文字色
-    str_color[ COLOR_CHAR_NAME ] = cf.get_option( "cl_char_name", CONF_COLOR_CHAR_NAME );
-
-    // トリップ等の名前欄の文字色
-    str_color[ COLOR_CHAR_NAME_B ] = cf.get_option( "cl_char_name_b", CONF_COLOR_CHAR_NAME_B );
-
-    // 名前無し時の名前欄の文字色
-    str_color[ COLOR_CHAR_NAME_NOMAIL ] = cf.get_option( "cl_char_name_nomail", CONF_COLOR_CHAR_NAME_NOMAIL );
-
-    // ageの時のメール欄の文字色
-    str_color[ COLOR_CHAR_AGE ] = cf.get_option( "cl_char_age", CONF_COLOR_CHAR_AGE );
-
-    // 選択範囲の文字色
-    str_color[ COLOR_CHAR_SELECTION ] = cf.get_option( "cl_char_selection", CONF_COLOR_CHAR_SELECTION );
-
-    // ハイライトの文字色
-    str_color[ COLOR_CHAR_HIGHLIGHT ] = cf.get_option( "cl_char_highlight", CONF_COLOR_CHAR_HIGHLIGHT );
-
-    // ブックマークの文字色
-    str_color[ COLOR_CHAR_BOOKMARK ] = cf.get_option( "cl_char_bookmark", CONF_COLOR_CHAR_BOOKMARK );
-
-    // リンク(通常)の文字色
-    str_color[ COLOR_CHAR_LINK ] = cf.get_option( "cl_char_link", CONF_COLOR_CHAR_LINK );
-
-    // リンク(複数)の文字色
-    str_color[ COLOR_CHAR_LINK_LOW ] = cf.get_option( "cl_char_link_low", CONF_COLOR_CHAR_LINK_LOW );
-
-    // リンク(多数)の文字色
-    str_color[ COLOR_CHAR_LINK_HIGH ] = cf.get_option( "cl_char_link_high", CONF_COLOR_CHAR_LINK_HIGH );
-
-    // メッセージビューの文字色
-    str_color[ COLOR_CHAR_MESSAGE ] = cf.get_option( "cl_char_message", CONF_COLOR_CHAR_MESSAGE );
-
-    // メッセージビュー(選択範囲)の文字色
-    str_color[ COLOR_CHAR_MESSAGE_SELECTION ] = cf.get_option( "cl_char_message_selection", CONF_COLOR_CHAR_MESSAGE_SELECTION );
-
-    // Gtk::Entryのデフォルトの文字色
-    str_color[ COLOR_CHAR_ENTRY_DEFAULT ] = MISC::get_entry_color_text();
-
-    // 画像(キャッシュ無)の色
-    str_color[ COLOR_IMG_NOCACHE ] = cf.get_option( "cl_img_nocache", CONF_COLOR_IMG_NOCACHE );
-
-    // 画像(キャッシュ有)の色
-    str_color[ COLOR_IMG_CACHED ] = cf.get_option( "cl_img_cached", CONF_COLOR_IMG_CACHED );
-
-    // 画像(ロード中)の色
-    str_color[ COLOR_IMG_LOADING ] = cf.get_option( "cl_img_loading", CONF_COLOR_IMG_LOADING );
-
-    // 画像(エラー)の色
-    str_color[ COLOR_IMG_ERR ] = cf.get_option( "cl_img_err", CONF_COLOR_IMG_ERR );
-
-    // スレ背景色
-    str_color[ COLOR_BACK ] = cf.get_option( "cl_back", CONF_COLOR_BACK );
-
-    // ポップアップの背景色
-    str_color[ COLOR_BACK_POPUP ] = cf.get_option( "cl_back_popup", CONF_COLOR_BACK_POPUP );
-
-    // 選択範囲の背景色
-    str_color[ COLOR_BACK_SELECTION ] = cf.get_option( "cl_back_selection", CONF_COLOR_BACK_SELECTION );
-
-    // ハイライトの背景色
-    str_color[ COLOR_BACK_HIGHLIGHT ] = cf.get_option( "cl_back_highlight", CONF_COLOR_HL );
-
-    // ハイライトの背景色(ツリー用)
-    str_color[ COLOR_BACK_HIGHLIGHT_TREE ] = cf.get_option( "cl_back_highlight_tree", CONF_COLOR_HL_TREE );
-
-    // メッセージビューの背景色
-    str_color[ COLOR_BACK_MESSAGE ] = cf.get_option( "cl_back_message", CONF_COLOR_BACK_MESSAGE );
-
-    // メッセージビューの選択色
-    str_color[ COLOR_BACK_MESSAGE_SELECTION ] = cf.get_option( "cl_back_message_selection", CONF_COLOR_BACK_MESSAGE_SELECTION );
-
-    // Gtk::Entryのデフォルトの背景色
-    str_color[ COLOR_BACK_ENTRY_DEFAULT ] = MISC::get_entry_color_base();
-
-    // 新着セパレータ
-    str_color[ COLOR_SEPARATOR_NEW ] = cf.get_option( "cl_sepa_new", CONF_COLOR_SEPARATOR_NEW );
-
-    // 板一覧の文字
-    str_color[ COLOR_CHAR_BBS ] = cf.get_option( "cl_chr_bbs", CONF_COLOR_CHAR_BBS );
-
-    // スレ一覧の文字
-    str_color[ COLOR_CHAR_BOARD ] = cf.get_option( "cl_chr_board", CONF_COLOR_CHAR_BOARD );
-
-    // 板一覧の背景色
-    str_color[ COLOR_BACK_BBS ] = cf.get_option( "cl_back_bbs", CONF_COLOR_BACK_BBS );
-
-    // 板一覧の背景色(偶数行)
-    str_color[ COLOR_BACK_BBS_EVEN ] = cf.get_option( "cl_back_bbs_even", CONF_COLOR_BACK_BBS_EVEN );
-
-    // スレ一覧の背景色
-    str_color[ COLOR_BACK_BOARD ] = cf.get_option( "cl_back_board", CONF_COLOR_BACK_BOARD );
-
-    // スレ一覧の背景色(偶数行)
-    str_color[ COLOR_BACK_BOARD_EVEN ] = cf.get_option( "cl_back_board_even", CONF_COLOR_BACK_BOARD_EVEN );
-
-    /////////////////////////
-
-
     // ツリービューでgtkrcの設定を使用するか
     use_tree_gtkrc = cf.get_option( "use_tree_gtkrc", CONF_USE_TREE_GTKRC );
 
     // ツリービューの行間スペース
     tree_ypad = cf.get_option( "tree_ypad", CONF_TREE_YPAD );
 
+    // 各ビューと枠との間の余白
+    view_margin = cf.get_option( "view_margin", CONF_VIEW_MARGIN );
+
     // スレ一覧で古いスレも表示
     show_oldarticle = cf.get_option( "show_oldarticle", CONF_SHOW_OLDARTICLE );
 
@@ -347,9 +253,24 @@ const bool ConfigItems::load()
     // スレビューのスクロール量(キー上下)
     key_scroll_size = cf.get_option( "key_scroll_size", CONF_KEY_SCROLL_SIZE );
 
+    // スレビューの高速スクロール量(キー上下・ ページ高 - 行高 * key_fastscroll_size )
+    key_fastscroll_size = cf.get_option( "key_fastscroll_size", CONF_KEY_FASTSCROLL_SIZE );
+
     // スレビューでリロード後に一番下までスクロール
     jump_after_reload = cf.get_option( "jump_after_reload", CONF_JUMP_AFTER_RELOAD );
 
+    // スレビューでリロード後に新着までスクロール
+    jump_new_after_reload = cf.get_option( "jump_new_after_reload", CONF_JUMP_NEW_AFTER_RELOAD );
+
+    // 実況モード
+    live_mode = cf.get_option( "live_mode", LIVE_SCRMODE_VARIABLE );
+
+    // 実況速度
+    live_speed = cf.get_option( "live_speed", CONF_LIVE_SPEED );
+
+    // 実況のスクロールモードを切り替えるしきい値
+    live_threshold = cf.get_option( "live_threshold", CONF_LIVE_THRESHOLD );
+
     // 板一覧でカテゴリを常にひとつだけ開く
     open_one_category = cf.get_option( "open_one_category", CONF_OPEN_ONE_CATEGORY );
 
@@ -359,6 +280,9 @@ const bool ConfigItems::load()
     // 書き込みログを保存
     save_postlog = cf.get_option( "save_postlog", CONF_SAVE_POSTLOG );
 
+    // 書き込みログの最大サイズ
+    maxsize_postlog = cf.get_option( "maxsize_postlog", CONF_MAXSIZE_POSTLOG );
+
     // 「書き込み中」のダイアログを表示しない
     hide_writing_dialog = cf.get_option( "hide_writing_dialog", CONF_HIDE_WRITING_DIALOG );
 
@@ -432,6 +356,12 @@ const bool ConfigItems::load()
     // タブにアイコンを表示するか
     show_tab_icon = cf.get_option( "show_tab_icon", CONF_SHOW_TAB_ICON );
 
+    // スレビューに書き込みマークを表示するか
+    show_post_mark = cf.get_option( "show_post_mark", CONF_SHOW_POST_MARK );
+
+    // ボタンをフラットにするか
+    flat_button = cf.get_option( "flat_button", CONF_FLAT_BUTTON );
+
     std::list< std::string > list_tmp;
     std::list< std::string >::iterator it_tmp;
     std::string str_tmp;
@@ -497,6 +427,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "restore_board", restore_board );
     cf.update( "restore_article", restore_article );
     cf.update( "restore_image", restore_image );
+    cf.update( "manage_winpos", manage_winpos );
     cf.update( "url_jdhp", url_jdhp );
     cf.update( "url_login2ch", url_login2ch );
     cf.update( "url_bbsmenu", url_bbsmenu );
@@ -570,7 +501,6 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cl_char_age", str_color[ COLOR_CHAR_AGE ] );
     cf.update( "cl_char_selection", str_color[ COLOR_CHAR_SELECTION ] );
     cf.update( "cl_char_highlight", str_color[ COLOR_CHAR_HIGHLIGHT ] );
-    cf.update( "cl_char_bookmark", str_color[ COLOR_CHAR_BOOKMARK ] );
     cf.update( "cl_char_link", str_color[ COLOR_CHAR_LINK ] );
     cf.update( "cl_char_link_low", str_color[ COLOR_CHAR_LINK_LOW ] );
     cf.update( "cl_char_link_high", str_color[ COLOR_CHAR_LINK_HIGH ] );
@@ -588,7 +518,10 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cl_back_message", str_color[ COLOR_BACK_MESSAGE ] );
     cf.update( "cl_back_message_selection", str_color[ COLOR_BACK_MESSAGE_SELECTION ] );
     cf.update( "cl_sepa_new", str_color[ COLOR_SEPARATOR_NEW ] );
+    cf.update( "cl_frame", str_color[ COLOR_FRAME ] );
+    cf.update( "cl_marker", str_color[ COLOR_MARKER ] );
     cf.update( "cl_chr_bbs", str_color[ COLOR_CHAR_BBS ] );
+    cf.update( "cl_chr_bbs_com", str_color[ COLOR_CHAR_BBS_COMMENT ] );
     cf.update( "cl_chr_board", str_color[ COLOR_CHAR_BOARD ] );
     cf.update( "cl_back_bbs", str_color[ COLOR_BACK_BBS ] );
     cf.update( "cl_back_bbs_even", str_color[ COLOR_BACK_BBS_EVEN ] );
@@ -599,6 +532,8 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "tree_ypad", tree_ypad );
 
+    cf.update( "view_margin", view_margin );
+
     cf.update( "show_oldarticle", show_oldarticle );
     cf.update( "newthread_hour", newthread_hour );
     cf.update( "inc_search_board", inc_search_board );
@@ -606,10 +541,18 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "tree_scroll_size", tree_scroll_size );
     cf.update( "scroll_size", scroll_size );
     cf.update( "key_scroll_size", key_scroll_size );
+    cf.update( "key_fastscroll_size", key_fastscroll_size );
     cf.update( "jump_after_reload", jump_after_reload );
+    cf.update( "jump_new_after_reload", jump_new_after_reload );
+
+    cf.update( "live_mode", live_mode );
+    cf.update( "live_speed", live_speed );
+    cf.update( "live_threshold", live_threshold );
+
     cf.update( "open_one_category", open_one_category );
     cf.update( "always_write_ok", always_write_ok );
     cf.update( "save_postlog", save_postlog );
+    cf.update( "maxsize_postlog", maxsize_postlog );
     cf.update( "hide_writing_dialog", hide_writing_dialog );
     cf.update( "fold_message", fold_message );
     cf.update( "margin_popup", margin_popup );
@@ -642,6 +585,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "tab_min_str", tab_min_str );
 
     cf.update( "show_tab_icon", show_tab_icon );
+    cf.update( "show_post_mark", show_post_mark );
+
+    cf.update( "flat_button", flat_button );
 
     // スレあぼーん情報
     std::string str_abone_word_thread = MISC::listtostr( list_abone_word_thread );
@@ -673,3 +619,126 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.save();
 }
+
+
+//
+// 色のセット
+//
+void ConfigItems::set_colors( JDLIB::ConfLoader& cf )
+{
+    // 文字色
+    str_color[ COLOR_CHAR ] = cf.get_option( "cl_char", CONF_COLOR_CHAR );
+
+    // 名前欄の文字色
+    str_color[ COLOR_CHAR_NAME ] = cf.get_option( "cl_char_name", CONF_COLOR_CHAR_NAME );
+
+    // トリップ等の名前欄の文字色
+    str_color[ COLOR_CHAR_NAME_B ] = cf.get_option( "cl_char_name_b", CONF_COLOR_CHAR_NAME_B );
+
+    // 名前無し時の名前欄の文字色
+    str_color[ COLOR_CHAR_NAME_NOMAIL ] = cf.get_option( "cl_char_name_nomail", CONF_COLOR_CHAR_NAME_NOMAIL );
+
+    // ageの時のメール欄の文字色
+    str_color[ COLOR_CHAR_AGE ] = cf.get_option( "cl_char_age", CONF_COLOR_CHAR_AGE );
+
+    // 選択範囲の文字色
+    str_color[ COLOR_CHAR_SELECTION ] = cf.get_option( "cl_char_selection", CONF_COLOR_CHAR_SELECTION );
+
+    // ハイライトの文字色
+    str_color[ COLOR_CHAR_HIGHLIGHT ] = cf.get_option( "cl_char_highlight", CONF_COLOR_CHAR_HIGHLIGHT );
+
+    // リンク(通常)の文字色
+    str_color[ COLOR_CHAR_LINK ] = cf.get_option( "cl_char_link", CONF_COLOR_CHAR_LINK );
+
+    // リンク(複数)の文字色
+    str_color[ COLOR_CHAR_LINK_LOW ] = cf.get_option( "cl_char_link_low", CONF_COLOR_CHAR_LINK_LOW );
+
+    // リンク(多数)の文字色
+    str_color[ COLOR_CHAR_LINK_HIGH ] = cf.get_option( "cl_char_link_high", CONF_COLOR_CHAR_LINK_HIGH );
+
+    // メッセージビューの文字色
+    str_color[ COLOR_CHAR_MESSAGE ] = cf.get_option( "cl_char_message", CONF_COLOR_CHAR_MESSAGE );
+
+    // メッセージビュー(選択範囲)の文字色
+    str_color[ COLOR_CHAR_MESSAGE_SELECTION ] = cf.get_option( "cl_char_message_selection", CONF_COLOR_CHAR_MESSAGE_SELECTION );
+
+    // Gtk::Entryのデフォルトの文字色
+    str_color[ COLOR_CHAR_ENTRY_DEFAULT ] = MISC::get_entry_color_text();
+
+    // 画像(キャッシュ無)の色
+    str_color[ COLOR_IMG_NOCACHE ] = cf.get_option( "cl_img_nocache", CONF_COLOR_IMG_NOCACHE );
+
+    // 画像(キャッシュ有)の色
+    str_color[ COLOR_IMG_CACHED ] = cf.get_option( "cl_img_cached", CONF_COLOR_IMG_CACHED );
+
+    // 画像(ロード中)の色
+    str_color[ COLOR_IMG_LOADING ] = cf.get_option( "cl_img_loading", CONF_COLOR_IMG_LOADING );
+
+    // 画像(エラー)の色
+    str_color[ COLOR_IMG_ERR ] = cf.get_option( "cl_img_err", CONF_COLOR_IMG_ERR );
+
+    // スレ背景色
+    str_color[ COLOR_BACK ] = cf.get_option( "cl_back", CONF_COLOR_BACK );
+
+    // ポップアップの背景色
+    str_color[ COLOR_BACK_POPUP ] = cf.get_option( "cl_back_popup", CONF_COLOR_BACK_POPUP );
+
+    // 選択範囲の背景色
+    str_color[ COLOR_BACK_SELECTION ] = cf.get_option( "cl_back_selection", CONF_COLOR_BACK_SELECTION );
+
+    // ハイライトの背景色
+    str_color[ COLOR_BACK_HIGHLIGHT ] = cf.get_option( "cl_back_highlight", CONF_COLOR_HL );
+
+    // ハイライトの背景色(ツリー用)
+    str_color[ COLOR_BACK_HIGHLIGHT_TREE ] = cf.get_option( "cl_back_highlight_tree", CONF_COLOR_HL_TREE );
+
+    // メッセージビューの背景色
+    str_color[ COLOR_BACK_MESSAGE ] = cf.get_option( "cl_back_message", CONF_COLOR_BACK_MESSAGE );
+
+    // メッセージビューの選択色
+    str_color[ COLOR_BACK_MESSAGE_SELECTION ] = cf.get_option( "cl_back_message_selection", CONF_COLOR_BACK_MESSAGE_SELECTION );
+
+    // Gtk::Entryのデフォルトの背景色
+    str_color[ COLOR_BACK_ENTRY_DEFAULT ] = MISC::get_entry_color_base();
+
+    // 新着セパレータ
+    str_color[ COLOR_SEPARATOR_NEW ] = cf.get_option( "cl_sepa_new", CONF_COLOR_SEPARATOR_NEW );
+
+    // ポップアップフレーム色
+    str_color[ COLOR_FRAME ] = cf.get_option( "cl_frame", CONF_COLOR_FRAME );
+
+    // オートスクロールマーカー色
+    str_color[ COLOR_MARKER ] = cf.get_option( "cl_marker", CONF_COLOR_MARKER );
+
+    // 板一覧の文字
+    str_color[ COLOR_CHAR_BBS ] = cf.get_option( "cl_chr_bbs", CONF_COLOR_CHAR_BBS );
+
+    // 板一覧のコメント
+    str_color[ COLOR_CHAR_BBS_COMMENT ] = cf.get_option( "cl_chr_bbs_com", CONF_COLOR_CHAR_BBS_COMENT );
+
+    // スレ一覧の文字
+    str_color[ COLOR_CHAR_BOARD ] = cf.get_option( "cl_chr_board", CONF_COLOR_CHAR_BOARD );
+
+    // 板一覧の背景色
+    str_color[ COLOR_BACK_BBS ] = cf.get_option( "cl_back_bbs", CONF_COLOR_BACK_BBS );
+
+    // 板一覧の背景色(偶数行)
+    str_color[ COLOR_BACK_BBS_EVEN ] = cf.get_option( "cl_back_bbs_even", CONF_COLOR_BACK_BBS_EVEN );
+
+    // スレ一覧の背景色
+    str_color[ COLOR_BACK_BOARD ] = cf.get_option( "cl_back_board", CONF_COLOR_BACK_BOARD );
+
+    // スレ一覧の背景色(偶数行)
+    str_color[ COLOR_BACK_BOARD_EVEN ] = cf.get_option( "cl_back_board_even", CONF_COLOR_BACK_BOARD_EVEN );
+}
+
+
+//
+// 色のリセット
+//
+void ConfigItems::reset_colors()
+{
+    // dummyのConfLoaderをset_colors()に渡してデフォルト値をセットする
+    JDLIB::ConfLoader cf( "", "dummy = dummy" );
+    set_colors( cf );
+}
