@@ -7,10 +7,12 @@
 #ifndef _INTERFACE_H
 #define _INTERFACE_H
 
+#include "etcboardinfo.h"
+
 #include <string>
 #include <list>
 #include <vector>
-#include <map>
+
 
 namespace XML
 {
@@ -58,18 +60,33 @@ namespace DBTREE
     // 移転した時は移転後のURLを返す
     const std::string is_board_moved( const std::string& url );
 
-    // 板を登録/移転などでアップデート
-    void update_board( const std::string& url, const std::string& name, const std::string& basicauth = std::string(), bool etc = false );
+    const std::string is_board_moved( const std::string& url,
+                                        std::string& old_root,
+                                        std::string& old_path_board,
+                                        std::string& new_root,
+                                        std::string& new_path_board
+        );
+
+    // 板移転
+    void move_board( const std::string& url_old, const std::string& url_new );
 
     // bbslist系
     const XML::Document& get_xml_document();
-    const std::map< std::string, std::string >& get_xml_etc();
+    const std::list< DBTREE::ETCBOARDINFO >& get_etcboards();
+    bool add_etc( const std::string& url, const std::string& name, const std::string& basicauth, const std::string& id );
+    bool move_etc( const std::string& url_old, const std::string& url_new,
+                   const std::string& name_old, const std::string& name_new,
+                   const std::string& basicauth, const std::string& boardid );
+    bool remove_etc( const std::string& url, const std::string& name );
+    void save_etc();
     void download_bbsmenu();
     
     // board 系
     const std::string board_path( const std::string& url );
     const std::string board_id( const std::string& url );
-    const time_t board_time_modified( const std::string& url );
+    const time_t board_time_modified( const std::string& url ); // 板の更新時間( time_t )
+    const std::string board_date_modified( const std::string& url ); // 板の更新時間( 文字列 )
+    void board_set_date_modified( const std::string& url, const std::string& date ); // 板の更新時間( 文字列 )をセット
     const std::string& board_get_modified_localrule( const std::string& url );
     void board_set_modified_localrule( const std::string& url, const std::string& modified );
     const std::string& board_get_modified_setting( const std::string& url );
@@ -122,6 +139,10 @@ namespace DBTREE
     const time_t board_samba_sec( const std::string& url );
     void board_set_samba_sec( const std::string& url, time_t sec );
     time_t board_write_leftsec( const std::string& url );
+    const int board_get_number_max_res( const std::string& url );
+    void board_set_number_max_res( const std::string& url, const int number );
+    const time_t board_get_live_sec( const std::string& url );
+    void board_set_live_sec( const std::string& url, time_t sec );
 
     // 全板の情報ファイル読み込み
     void read_boardinfo_all();
@@ -137,7 +158,7 @@ namespace DBTREE
     const std::string article_key( const std::string& url ); // idから拡張子を取ったもの。書き込み用
     const time_t article_since_time( const std::string& url );
     const std::string article_since_date( const std::string& url );
-    const time_t article_time_modified( const std::string& url ); // 更新時間( size_t )
+    const time_t article_time_modified( const std::string& url ); // スレの更新時間( time_t )
     const std::string article_date_modified( const std::string& url ); // スレの更新時間( 文字列 )
     const int article_hour( const std::string& url );
     const time_t article_write_time( const std::string& url );
@@ -295,6 +316,7 @@ namespace DBTREE
     void set_bookmarked_thread( const std::string& url, bool bookmarked );
 
     // レスのブックマーク
+    const int get_num_bookmark( const std::string& url );
     const bool is_bookmarked( const std::string& url, int number );
     void set_bookmark( const std::string& url, int number, bool set );
 }
