@@ -5,17 +5,25 @@
 
 #include "window.h"
 
+#include "config/globalconf.h"
+
 #include "global.h"
 #include "session.h"
 #include "dndmanager.h"
 #include "command.h"
 
 
-#define FOCUSOUT_TIMEOUT 250 // msec
-#define FOCUS_TIME  100 //msec
-#define UNGRAB_TIME 100 //msec
+enum
+{
+    MGINFO_CHARS = MAX_MG_LNG * 2 + 16, // マウスジェスチャ表示欄の文字数
+
+    FOCUSOUT_TIMEOUT = 250, // GNOME環境でフォーカスを外すまでの時間 ( msec )
+    FOCUS_TIME = 100, // JDWindowにフォーカスを移してウィンドウサイズを復元するまでの時間 ( msec )
+    UNGRAB_TIME = 100, // ブート直後にフォーカスをメインウィンドウに戻すまでの時間 ( msec )
+
+    JDWIN_FOLDSIZE = 10  // 折りたたみ時に指定するウィンドウ高さ
+};
 
-#define JDWIN_FOLDSIZE 10
 
 // ウィンドウ状態
 enum
@@ -36,10 +44,12 @@ enum
 
 using namespace SKELETON;
 
-JDWindow::JDWindow( const bool fold_when_focusout )
+// メッセージウィンドウでは m_mginfo が不要なので need_mginfo = false になる
+JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     : Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
+      m_win_moved( false ),
       m_fold_when_focusout( fold_when_focusout ),
-      m_boot( fold_when_focusout ),
+      m_boot( true ),
       m_enable_fold( m_fold_when_focusout ),
       m_transient( false ),
       m_mode( JDWIN_INIT ),
@@ -50,18 +60,24 @@ JDWindow::JDWindow( const bool fold_when_focusout )
 {
     // ステータスバー
 #if GTKMMVER <= 240
-    m_statbar.pack_start( m_mginfo );
+    if( need_mginfo ) m_statbar.pack_start( m_mginfo );
 #else
-    m_statbar.pack_start( m_label_stat, Gtk::PACK_SHRINK );
-    m_statbar.pack_end( m_mginfo, Gtk::PACK_SHRINK );
-    m_mginfo.set_width_chars( MAX_MG_LNG * 2 + 16 );
-    m_mginfo.set_justify( Gtk::JUSTIFY_LEFT );
-#endif
-    m_statbar.show_all_children();
+    m_label_stat.set_size_request( 0, -1 );
+    m_label_stat.set_alignment( Gtk::ALIGN_LEFT );
+    m_label_stat.set_selectable( true );
+    m_label_stat.set_single_line_mode( true );
 
-    m_stat_scrbar.add( m_statbar );
-    m_stat_scrbar.set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_NEVER );
-    m_stat_scrbar.set_size_request( 8 );
+    m_label_stat_ebox.add( m_label_stat );
+    m_label_stat_ebox.set_visible_window( false );
+
+    m_statbar.pack_start( m_label_stat_ebox );
+    if( need_mginfo ) m_statbar.pack_start( m_mginfo, Gtk::PACK_SHRINK );
+
+    m_mginfo.set_width_chars( MGINFO_CHARS );
+    m_mginfo.set_alignment( Gtk::ALIGN_LEFT );
+#endif
+
+    m_statbar.show_all_children();
 
     add( m_vbox );
 }
@@ -97,7 +113,7 @@ void JDWindow::init_win()
 
         set_skip_taskbar_hint( true );
         resize( get_width_win(), 1 );
-        move( get_x_win(), get_y_win() );
+        move_win( get_x_win(), get_y_win() );
         focus_out();
 
         property_window_position().set_value( Gtk::WIN_POS_NONE );
@@ -109,10 +125,12 @@ void JDWindow::init_win()
     // 通常のウィンドウ
     else{
         resize( get_width_win(), get_height_win() );
-        move( get_x_win(), get_y_win() );
+        move_win( get_x_win(), get_y_win() );
         if( is_maximized_win() ) maximize_win();
         property_window_position().set_value( Gtk::WIN_POS_NONE );
         set_shown_win( true );
+
+        Glib::signal_idle().connect( sigc::mem_fun( *this, &JDWindow::slot_idle ) );
     }
 }
 
@@ -120,20 +138,24 @@ void JDWindow::init_win()
 bool JDWindow::slot_idle()
 {
     // ブート完了
-    if( m_fold_when_focusout && m_boot ){
+    if( m_boot ){
 
 #ifdef _DEBUG
         std::cout << "----------------\nJDWinow::slot_idle boot end mode = " << m_mode << std::endl;
 #endif
         m_boot = false;
+        move_win( get_x_win(), get_y_win() );
 
-        // 遅延させて clock_in()の中でフォーカスをメインウィンドウに戻す
-        if( m_mode == JDWIN_FOLD ){
-            m_mode = JDWIN_UNGRAB;
-            m_counter = 0;
+        if( m_fold_when_focusout ){
+
+            // 遅延させて clock_in()の中でフォーカスをメインウィンドウに戻す
+            if( m_mode == JDWIN_FOLD ){
+                m_mode = JDWIN_UNGRAB;
+                m_counter = 0;
+            }
+
+            CORE::core_set_command( "window_boot_fin" );
         }
-
-        CORE::core_set_command( "window_boot_fin" );
     }
 
     return false;
@@ -225,6 +247,72 @@ void JDWindow::maximize_win()
 }
 
 
+//
+// ウィンドウ移動
+// 
+void JDWindow::move_win( const int x, const int y )
+{
+    if( ! CONFIG::get_manage_winpos() ) return;
+
+#ifdef _DEBUG
+    std::cout << "JDWindow::move_win "
+              << "x = " << x << " y = " << y << std::endl;
+#endif
+
+    move( x, y );
+    set_x_win( x );
+    set_y_win( y );
+
+    // compiz 環境などでは move() で指定した座標がズレるので補正する
+    m_win_moved = true;
+}
+
+
+//
+// ウィンドウ座標取得
+//
+void JDWindow::set_win_pos()
+{
+    if( ! get_window() ) return;
+
+    int x,y;
+    get_window()->get_root_origin( x, y );
+
+#ifdef _DEBUG
+    std::cout << "JDWindow::set_win_pos "
+              << "x = " << x << " / " << get_x_win() << ", y = " << y << " / " << get_y_win() << std::endl;
+#endif
+
+    // compiz 環境などでは move() で指定した座標がズレるので補正する
+    if( m_win_moved ){
+
+        if( x != get_x_win() || y != get_y_win() ){
+
+            // 補正量がmrgを越えたら補正を諦める
+            const int mrg = 64;
+
+            const int delta_x = x - get_x_win();
+            const int delta_y = y - get_y_win();
+
+            x = get_x_win();
+            y = get_y_win();
+            m_win_moved = false;
+
+            if( abs( delta_x ) <= mrg && abs( delta_y ) <= mrg ){
+
+                move( get_x_win() - delta_x, get_y_win() - delta_y );
+#ifdef _DEBUG
+                std::cout << "!!! moved x = " << get_x_win() << " y = " << get_y_win() << " dx = " << delta_x << " dy = " << delta_y << std::endl;
+#endif
+            }
+        }
+    }
+
+    set_x_win( x );
+    set_y_win( y );
+}
+
+
 // hide 中
 const bool JDWindow::is_hide()
 {
@@ -261,6 +349,27 @@ void JDWindow::pack_remove_end( bool unpack, Widget& child, Gtk::PackOptions opt
 // ステータスバー表示
 void JDWindow::set_status( const std::string& stat )
 {
+    if( stat == m_status ) return;
+
+    m_status = stat;
+
+#if GTKMMVER <= 240
+    m_statbar.push( stat );
+#else
+    m_label_stat.set_text( stat );
+    m_tooltip.set_tip( m_label_stat_ebox, stat );
+#endif
+}
+
+
+// 一時的にステータスバーの表示を変える( マウスオーバーでのURL表示用 )
+//
+// 恒久的に変えてしまうと、マウススオ-バー中に ArticleViewBase では
+// ないクラスから表示を変更された場合に本来の表示に戻せなくなる。
+void JDWindow::set_status_temporary( const std::string& stat )
+{
+    if( stat == m_status ) return;
+
 #if GTKMMVER <= 240
     m_statbar.push( stat );
 #else
@@ -268,11 +377,21 @@ void JDWindow::set_status( const std::string& stat )
 #endif
 }
 
+// 一時的に変えたステータスバーの表示を戻す
+void JDWindow::restore_status()
+{
+#if GTKMMVER <= 240
+    m_statbar.push( m_status );
+#else
+    m_label_stat.set_text( m_status );
+#endif
+}
+
 
 // マウスジェスチャ表示
 void JDWindow::set_mginfo( const std::string& mginfo )
 {
-    m_mginfo.set_text( mginfo );
+    if( m_mginfo.is_realized() ) m_mginfo.set_text( mginfo );
 }
 
 
@@ -343,7 +462,7 @@ void JDWindow::focus_in()
         if( ! is_maximized_win() && get_window() ){
             int x, y;
             get_window()->get_root_origin( x, y );
-            if( x != get_x_win() || y != get_y_win() ) move( get_x_win(), get_y_win() );
+            if( x != get_x_win() || y != get_y_win() ) move_win( get_x_win(), get_y_win() );
         }
 
 
@@ -460,12 +579,7 @@ bool JDWindow::on_delete_event( GdkEventAny* event )
         else{
 
             // hideする前に座標保存
-            if( ! is_maximized_win() && ! is_iconified_win() && get_window() ){
-                int x, y;
-                get_window()->get_root_origin( x, y );
-                set_x_win( x );
-                set_y_win( y );
-            }
+            if( ! is_maximized_win() && ! is_iconified_win() && get_window() ) set_win_pos();
 
             hide();
             m_mode = JDWIN_HIDE;
@@ -496,8 +610,8 @@ bool JDWindow::on_window_state_event( GdkEventWindowState* event )
         // 通常 -> アイコン化
         if( ! is_iconified_win() && iconified ) set_shown_win( false );
 
-        // アイコン → 通常
-        else if( is_iconified_win() && ! iconified ) set_shown_win( true );
+        // アイコン -> 通常
+        else if( is_iconified_win() && ! iconified && m_mode != JDWIN_FOLD ) set_shown_win( true );
 
         // 通常 -> 最大化
         if( ! is_maximized_win() && maximized ){
@@ -531,16 +645,22 @@ bool JDWindow::on_window_state_event( GdkEventWindowState* event )
 bool JDWindow::on_configure_event( GdkEventConfigure* event )
 {
     const int mrg = 16;
+    const int width_new = event->width;
+    const int height_new = event->height;
     int min_height = 0;
     if( m_scrwin ) min_height = m_vbox.get_height() - m_scrwin->get_height() + mrg;
 
-#ifdef _DEBUG
-    std::cout << "JDWindow::on_configure_event\n"
-              << " w = " << get_width() << " h = " << get_height() << " min_height = " << min_height << "\n------->\n";
-#endif
-
     if( ! m_boot ){
 
+#ifdef _DEBUG
+    std::cout << "JDWindow::on_configure_event"
+              << " boot = " << m_boot
+              << " mode = " << m_mode
+              << " x = " << event->x << " y = " << event->y
+              << " w = " << width_new << " h = " << height_new
+              << " min_height = " << min_height << std::endl;
+#endif
+
         // 最大 -> 通常に戻る時はリサイズをキャンセル
         if( m_mode == JDWIN_UNMAX ) m_mode = JDWIN_NORMAL;
         else if( m_mode == JDWIN_UNMAX_FOLD ) m_mode = JDWIN_FOLD;
@@ -548,28 +668,25 @@ bool JDWindow::on_configure_event( GdkEventConfigure* event )
         // 最大、最小化しているときは除く
         else if( ! is_maximized_win() && ! is_iconified_win() ){
 
-            if( get_window() ){
-                int x,y;
-                get_window()->get_root_origin( x, y );
-                set_x_win( x );
-                set_y_win( y );
-            }
+            set_win_pos();
 
             // サイズ変更
-            if( ( ! m_fold_when_focusout || m_mode == JDWIN_FOLD ) && get_height() > min_height ){
-                set_width_win( get_width() );
-                set_height_win( get_height() );
+            if( ( ! m_fold_when_focusout || m_mode == JDWIN_NORMAL || m_mode == JDWIN_FOLD )
+                && height_new > min_height
+                ) {
+                set_width_win( width_new );
+                set_height_win( height_new );
             }
         }
-    }
 
 #ifdef _DEBUG
-    std::cout << " mode = " << m_mode << " show = " << is_shown_win() << std::endl
+    std::cout << "configure fin --> mode = " << m_mode << " show = " << is_shown_win() 
               << " maximized = " << is_maximized_win()
               << " iconified = " << is_iconified_win()
               << " x = " << get_x_win() << " y = " << get_y_win()
               << " w = " << get_width_win() << " height = " << get_height_win() << std::endl;
 #endif     
+    }
 
     return Gtk::Window::on_configure_event( event );
 }
